| Title: | More Flexible Form of Boolean Verbose |
|---|---|
| Description: | R functions are not supposed to print text without giving the user the option to turn the printing off or on using a Boolean 'verbose' in a construct like 'if(verbose) print(...)'. But this black/white approach is rather rigid, and an approach with shades of gray might be more appropriate in many circumstances. |
| Authors: | Barry Zeeberg [aut, cre] |
| Maintainer: | Barry Zeeberg <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.2 |
| Built: | 2026-06-01 07:39:16 UTC |
| Source: | https://github.com/cran/vprint |
more flexible form of if(verbose) print(...)
vprint(class, verbose = NULL, txt)vprint(class, verbose = NULL, txt)
class |
integer representing the verbose class |
verbose |
integer vector representing classes |
txt |
argument to print |
if you are the developer, and you have some debug statements rather than comment them out, you can turn them off and on likewise, a user can request more or less informational comments
suggested standardized class codes for vprint():
-1 = developer debugging only
0 = constitutively turned on
1 = help for new user
2 = follow progress of long computation
3 = primary results
4 = meta info (e.g. dims of a mat before/after trimming)
5 = warnings
6 = errors
Note that the class argument is hardwired into the function code by the developer. For example, for a debugging statement, '-1' is hardwired in. The choice of whether or not to display this message is subsequently governed by the user selecting which values to include in the 'verbose' vector parameter.
returns no values but has side effect of printing some text
vprint(1,1:2,"try me") vprint(0,1:2,"try me") vprint(3,1:2,"try me")vprint(1,1:2,"try me") vprint(0,1:2,"try me") vprint(3,1:2,"try me")